MappedMutexGuard

Struct MappedMutexGuard 

pub struct MappedMutexGuard<'a, T: ?Sized + 'a> {
    data: NonNull<T>,
    inner: &'a Mutex,
    _variance: PhantomData<&'a mut T>,
}
🔬This is a nightly-only experimental API. (mapped_lock_guards #117108)
An RAII mutex guard returned by MutexGuard::map, which can point to a subfield of the protected data. When this structure is dropped (falls out of scope), the lock will be unlocked.

The main difference between MappedMutexGuard and MutexGuard is that the former cannot be used with Condvar, since that could introduce soundness issues if the locked object is modified by another thread while the Mutex is unlocked.

The data protected by the mutex can be accessed through this guard via its Deref and DerefMut implementations.

This structure is created by the map and filter_map methods on MutexGuard.

Fields

data: NonNull<T>
🔬This is a nightly-only experimental API. (mapped_lock_guards #117108)
inner: &'a Mutex
🔬This is a nightly-only experimental API. (mapped_lock_guards #117108)
_variance: PhantomData<&'a mut T>
🔬This is a nightly-only experimental API. (mapped_lock_guards #117108)

Implementations

Source

impl<'a, T: ?Sized> MappedMutexGuard<'a, T>

pub fn map<U, F>(orig: Self, f: F) -> MappedMutexGuard<'a, U>
where F: FnOnce(&mut T) -> &mut U, U: ?Sized,

🔬This is a nightly-only experimental API. (mapped_lock_guards #117108)

Makes a MappedMutexGuard for a component of the borrowed data, e.g. an enum variant.

The Mutex is already locked, so this cannot fail.

This is an associated function that needs to be used as MappedMutexGuard::map(...). A method would interfere with methods of the same name on the contents of the MutexGuard used through Deref.

pub fn filter_map<U, F>( orig: Self, f: F, ) -> Result<MappedMutexGuard<'a, U>, Self>
where F: FnOnce(&mut T) -> Option<&mut U>, U: ?Sized,

🔬This is a nightly-only experimental API. (mapped_lock_guards #117108)

Makes a MappedMutexGuard for a component of the borrowed data. The original guard is returned as an Err(...) if the closure returns None.

The Mutex is already locked, so this cannot fail.

This is an associated function that needs to be used as MappedMutexGuard::filter_map(...). A method would interfere with methods of the same name on the contents of the MutexGuard used through Deref.